Adds sections 1 to 8 to the report so that the first title points to the standard report section 9 "Inclusion".
Examples
officer::read_docx() %>%
body_add_gr_sections_1_8() %>%
crosstable::write_and_open()
Adds sections 1 to 8 to the report so that the first title points to the standard report section 9 "Inclusion".
officer::read_docx() %>%
body_add_gr_sections_1_8() %>%
crosstable::write_and_open()