Skip to contents

[Experimental]
The function aggregate_recist_rates() creates a summary table of recist for each possible response. The resulting dataframe can be piped to as_flextable() to get a nicely formatted flextable.

Usage

aggregate_recist_rates(data, ..., derived_endpoints = c("ORR", "CBR", "DCR"))

# S3 method for class 'aggregate_recist_rates'
as_flextable(x, ...)

Arguments

data

A dataset containing longitudinal RECIST data in long format.

...

unused

derived_endpoints

Character; Derived endpoints to compute from BOR. One or several of c("ORR", "CBR", "DCR"). See vignette("BOR") for endpoint definitions.

x

a dataframe, resulting of aggregate_recist_rates()

Value

a dataframe (aggregate_recist_rates()) or a flextable (as_flextable()).

a formatted flextable

Examples

recist = grstat_example()$recist
recist %>%
 calc_best_response(rc_resp = "rcresp", rc_date = "rcdt",
                    subjid = "subjid", rc_sum = "rctlsum", confirmed = FALSE) %>%
 aggregate_recist_rates(derived_endpoints=c("ORR", "CBR", "DCR")) %>%
 as_flextable()
#> Warning: Function `calc_best_response()` (`?grstat::calc_best_response()`) is not yet
#> validated and may produce incorrect results.
#> ! Always double-check the results using your own code.
#>  Please send your feedback to the grstat team.
#> This warning is displayed once every 8 hours.
#> Warning: Target Lesions Length Sum is missing at baseline. (2 patients: #72 and #193)

Unconfirmed Best Response during treatment

N=200

%

IC 95%*

Complete response

98

49.0

[41.9;56.1]

Partial response

27

13.5

[9.1;19]

Stable disease

16

8.0

[4.6;12.7]

Progressive disease

59

29.5

[23.3;36.3]

Not evaluable

0

0.0

[0;1.8]

Objective Response Rate (ORR)ORR

125

62.5

[55.4;69.2]

Clinical Benefit Rate (CBR)CBR

125

62.5

[55.4;69.2]

Disease Control Rate (DCR)DCR

141

70.5

[63.7;76.7]

*Clopper-Pearson (Exact) method was used for confidence interval

ORRORR was defined as the presence of a partial response (PR) or a complete response (CR).

CBRCBR was defined as the presence of a partial response (PR), a complete response (CR), or a stable disease (SD) lasting at least six months.

DCRDCR was defined as the presence of a partial response (PR), a complete response (CR), or a stable disease (SD).

#It is also possible to use the confirmation method for the ORR recist %>% calc_best_response(rc_resp = "rcresp", rc_date = "rcdt", subjid = "subjid", rc_sum = "rctlsum", confirmed = TRUE) %>% aggregate_recist_rates(derived_endpoints=c("ORR")) %>% as_flextable() #> Warning: Target Lesions Length Sum is missing at baseline. (2 patients: #72 and #193)

Confirmed Best Response during treatment**

N=200

%

IC 95%*

Complete response

83

41.5

[34.6;48.7]

Partial response

18

9.0

[5.4;13.9]

Stable disease

40

20.0

[14.7;26.2]

Progressive disease

59

29.5

[23.3;36.3]

Not evaluable

0

0.0

[0;1.8]

Objective Response Rate (ORR)ORR

101

50.5

[43.4;57.6]

*Clopper-Pearson (Exact) method was used for confidence interval

**For CR & PR, confirmation of response had to be be demonstrated with an assessment 4 weeks or later from the initial response for response.

ORRORR was defined as the presence of a partial response (PR) or a complete response (CR).